pub fn probe(path: impl AsRef<Path>) -> Result<ProbeResult>Expand description
Probe a file using binaries discovered on the current PATH.
pub fn probe(path: impl AsRef<Path>) -> Result<ProbeResult>Probe a file using binaries discovered on the current PATH.